AudioSource

Enum AudioSource 

pub enum AudioSource {
    Default = 0,
    Mic = 1,
    Camcorder = 5,
    VoiceRecognition = 6,
    VoiceCommunication = 7,
}
Audio source type

Defines various audio input sources supported by the Android audio system. Different audio sources are suitable for different application scenarios.

Examples

use android_media::AudioSource;
let source = AudioSource::Mic;
assert_eq!(source.value(), 1);

Variants



Default = 0

Default audio source



Mic = 1

Main microphone - most commonly used recording source



Camcorder = 5

Camera audio - used for video recording



VoiceRecognition = 6

Voice recognition - optimized for speech recognition scenarios with noise suppression



VoiceCommunication = 7

Voice communication - optimized for call scenarios with echo cancellation

Implementations

Source

impl AudioSource

pub const fn value(&self) -> i32

Get the integer value of the audio source

Returns

Returns the audio source identifier in the Android system

Examples
use android_media::AudioSource;
assert_eq!(AudioSource::Mic.value(), 1);