ChannelOutConfig

Enum ChannelOutConfig 

pub enum ChannelOutConfig {
    Mono = 4,
    Stereo = 12,
}
Audio channel configuration - Output (Player)

Defines channel configurations for audio output (playback), supporting mono and stereo.

Examples

use android_media::ChannelOutConfig;
let config = ChannelOutConfig::Mono;
assert_eq!(config.value(), 4);
assert_eq!(config.channel_count(), 1);

Variants



Mono = 4

Mono playback - suitable for voice announcements, etc.



Stereo = 12

Stereo playback - suitable for music playback, etc.

Implementations

Source

impl ChannelOutConfig

pub const fn value(&self) -> i32

Get the integer value of the channel configuration

Returns

Returns the channel configuration identifier in the Android system

Examples
use android_media::ChannelOutConfig;
assert_eq!(ChannelOutConfig::Mono.value(), 4);
pub const fn channel_count(&self) -> i32

Get the number of channels

Returns

Returns the number of channels in this configuration (1 = mono, 2 = stereo)

Examples
use android_media::ChannelOutConfig;
assert_eq!(ChannelOutConfig::Mono.channel_count(), 1);
assert_eq!(ChannelOutConfig::Stereo.channel_count(), 2);