pub enum ChannelInConfig {
Mono = 16,
Stereo = 12,
}Expand description
Audio channel configuration - Input (Microphone)
Defines channel configurations for audio input (recording), supporting mono and stereo. Different channel configurations affect recording quality and storage space.
Examples
use android_media::ChannelInConfig;
let config = ChannelInConfig::Mono;
assert_eq!(config.value(), 16);
assert_eq!(config.channel_count(), 1);Variants
Mono = 16
Mono recording - each sample point contains data from one channel
Stereo = 12
Stereo recording - each sample point contains data from left and right channels
Implementations
Sourceimpl ChannelInConfig
impl ChannelInConfig